@@ -1,5 +1,5 @@
 /* GDA library
- * Copyright (C) 2006 The GNOME Foundation.
+ * Copyright (C) 2006 - 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -23,14 +23,33 @@
 #ifndef __GDA_CONNECTION_PRIVATE_H_
 #define __GDA_CONNECTION_PRIVATE_H_
 
+#include <libgda/gda-meta-store.h>
+#include <providers-support/gda-pstmt.h>
+
 G_BEGIN_DECLS
 
+/*
+ * Provider's specific connection data management
+ */
+void     gda_connection_internal_set_provider_data (GdaConnection *cnc, gpointer data, GDestroyNotify destroy_func);
+gpointer gda_connection_internal_get_provider_data (GdaConnection *cnc);
+
+/*
+ * Connection's events
+ */
+void                 gda_connection_add_event            (GdaConnection *cnc, GdaConnectionEvent *event);
+GdaConnectionEvent  *gda_connection_add_event_string     (GdaConnection *cnc, const gchar *str, ...);
+void                 gda_connection_clear_events_list    (GdaConnection *cnc);
+
+/*
+ * Transaction related
+ */
 void gda_connection_internal_transaction_started (GdaConnection *cnc, const gchar *parent_trans, const gchar *trans_name, 
 						  GdaTransactionIsolation isol_level);
 void gda_connection_internal_transaction_rolledback (GdaConnection *cnc, const gchar *trans_name);
 void gda_connection_internal_transaction_committed (GdaConnection *cnc, const gchar *trans_name);
 
-void gda_connection_internal_sql_executed (GdaConnection *cnc, const gchar *sql, GdaConnectionEvent *error);
+void gda_connection_internal_statement_executed (GdaConnection *cnc, GdaStatement *stmt, GdaSet *params, GdaConnectionEvent *error);
 
 void gda_connection_internal_savepoint_added (GdaConnection *cnc, const gchar *parent_trans, const gchar *svp_name);
 void gda_connection_internal_savepoint_rolledback (GdaConnection *cnc, const gchar *svp_name);
@@ -38,8 +57,12 @@ void gda_connection_internal_savepoint_removed (GdaConnection *cnc, const gchar
 void gda_connection_internal_change_transaction_state (GdaConnection *cnc,
 						       GdaTransactionStatusState newstate);
 
-/* helper function, fuzzy analysis of "standard" SQL for transactions */
-void gda_connection_internal_treat_sql (GdaConnection *cnc, const gchar *sql, GdaConnectionEvent *error);
+/* 
+ * prepared statements support
+ */
+void      gda_connection_add_prepared_statement (GdaConnection *cnc, GdaStatement *gda_stmt, GdaPStmt *prepared_stmt); 
+void      gda_connection_del_prepared_statement (GdaConnection *cnc, GdaStatement *gda_stmt); 
+GdaPStmt *gda_connection_get_prepared_statement (GdaConnection *cnc, GdaStatement *gda_stmt);
 
 G_END_DECLS
 
