@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 2006 - 2008 The GNOME Foundation.
+ * Copyright (C) 2006 - 2009 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -45,6 +45,12 @@ struct _GdaDataAccessWrapper {
 
 struct _GdaDataAccessWrapperClass {
 	GObjectClass                   parent_class;
+
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
+	void (*_gda_reserved3) (void);
+	void (*_gda_reserved4) (void);
 };
 
 GType         gda_data_access_wrapper_get_type    (void) G_GNUC_CONST;
