@@ -479,9 +479,8 @@ get_connection_type_list (PostgresConnectionData *cdata)
 		/* main query to fetch infos about the data types */
 		query = g_strdup_printf (
                           "SELECT t.oid, t.typname, u.usename, pg_catalog.obj_description(t.oid), t.typinput "
-			  "FROM pg_catalog.pg_type t, pg_catalog.pg_user u, pg_catalog.pg_namespace n "
-			  "WHERE t.typowner=u.usesysid "
-			  "AND n.oid = t.typnamespace "
+			  "FROM pg_catalog.pg_type t LEFT JOIN pg_catalog.pg_user u ON (t.typowner=u.usesysid), pg_catalog.pg_namespace n "
+			  "WHERE n.oid = t.typnamespace "
 			  "AND pg_catalog.pg_type_is_visible(t.oid) "
 			  /*--AND (n.nspname = 'public' OR n.nspname = 'pg_catalog')*/
 			  "AND typname !~ '^_' "
@@ -520,6 +519,8 @@ get_connection_type_list (PostgresConnectionData *cdata)
 	nrows = PQntuples (pg_res);
 	td = g_new (GdaPostgresTypeOid, nrows);
 	h_table = g_hash_table_new (g_direct_hash, g_direct_equal);
+	if (nrows == 0)
+		g_warning ("PostgreSQL provider did not find any data type (expect some mis-behaviours) please report the error to bugzilla.gnome.org");
 	for (i = 0; i < nrows; i++) {
 		gchar *conv_func_name = NULL;
 		if (PQnfields (pg_res) >= 5)
@@ -908,12 +909,13 @@ gda_postgres_provider_create_operation (GdaServerProvider *provider, GdaConnecti
 	dir = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, NULL);
         file = gda_server_provider_find_file (provider, dir, str);
 	g_free (dir);
-        g_free (str);
 
         if (! file) {
-                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
+		g_free (str);
                 return NULL;
         }
+        g_free (str);
 
         op = gda_server_operation_new (type, file);
         g_free (file);
@@ -946,12 +948,13 @@ gda_postgres_provider_render_operation (GdaServerProvider *provider, GdaConnecti
 	dir = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, NULL);
         file = gda_server_provider_find_file (provider, dir, str);
 	g_free (dir);
-        g_free (str);
 
         if (! file) {
-                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
+		g_free (str);
                 return NULL;
         }
+        g_free (str);
         if (!gda_server_operation_is_valid (op, file, error)) {
                 g_free (file);
                 return NULL;
